@@ -35,7 +35,8 @@ TEXTDOMAIN=antixcc.sh
 #antix-moka=moka icons used on earlier releases
 
 #ICONS=/usr/share/icons/antix-moka
-ICONS=/usr/share/icons/antix-faenza
+#ICONS=/usr/share/icons/antix-faenza
+ICONS=/usr/share/icons/antix-numix
 ICONS2=/usr/share/pixmaps
 
 EXCLUDES_DIR=/usr/local/share/excludes 
@@ -56,7 +57,7 @@ its_alive && ITS_ALIVE=true
 
 Desktop=$"Desktop" System=$"System" Network=$"Network" Shares=$"Shares" Session=$"Session"
 Live=$"Live" Disks=$"Disks" Hardware=$"Hardware" Drivers=$"Drivers" Maintenance=$"Maintenance"
-dpi_label=$(printf "%s (DPI)" $"Set Font Size")
+dpi_label=$(printf "%s DPI" $"Set Font Size")
 
 vbox() {
     local text="$*"
@@ -157,13 +158,13 @@ test -x  /usr/sbin/bootrepair && bootrepair_entry=$(entry \
 test -x /usr/bin/wicd-gtk && wicd_entry=$(entry \
     $ICONS/wicd-gtk.png \
     "wicd-gtk &" \
-    $"Connect Wirelessly (wicd)")
+    $"WiFi Connect (Wicd)")
 
 firewall_prog=/usr/bin/gufw
 test -x $firewall_prog  && firewall_entry=$(entry \
     $ICONS/firewall.png \
     "gksu gufw &" \
-    $"Manage Firewall")
+    $"Firewall Configuration")
 
 backup_prog=/usr/bin/luckybackup
 test -x $backup_prog  && backup_entry=$(entry \
@@ -187,7 +188,7 @@ printer_prog=/usr/bin/system-config-printer
 test -x $printer_prog  && printer_entry=$(entry \
     $ICONS2/hplj1020_icon.png \
     "system-config-printer &" \
-    $"Setup Printer")
+    $"Print Settings")
 
 livekernel_prog=/usr/local/bin/live-kernel-updater
 test -x $livekernel_prog && livekernel_entry=$(entry \
@@ -254,7 +255,7 @@ ceni_prog=/usr/bin/ceni
 test -x $ceni_prog && ceni_entry=$(entry \
     $ICONS/network-wired.png \
     "desktop-defaults-run -t sudo ceni &" \
-    $"Network Interfaces (ceni)")
+    $"Network Interfaces (Ceni)")
 
 umts_prog=/usr/bin/umts-panel
 test -x $umts_prog && umts_entry=$(entry \
@@ -266,11 +267,11 @@ connectshares_prog=/usr/local/bin/connectshares-config
 test -x $connectshares_prog && connectshares_entry=$(entry \
     $ICONS/connectshares-config.png \
     "connectshares-config &" \
-    $"Configure ConnectShares")
+    $"ConnectShares Configuration")
 
 disconnectshares_prog=/usr/local/bin/disconnectshares
 test -x $disconnectshares_prog && disconnectshares_entry=$(entry \
-    $ICONS/connectshares.png \
+    $ICONS/disconnectshares.png \
     "disconnectshares &" \
     $" DisconnectShares")
 
@@ -278,7 +279,7 @@ droopy_prog=/usr/local/bin/droopy.sh
 test -x $droopy_prog && droopy_entry=$(entry \
     $ICONS2/droopy.png \
     "droopy.sh &" \
-    $"Share Files via Droopy")
+    $"Droopy (File Sharing)")
 
 assistant_prog=/usr/local/bin/1-to-1_assistance.sh
 test -x $assistant_prog && assistant_entry=$(entry \
@@ -302,13 +303,13 @@ gnomeppp_prog=/usr/bin/gnome-ppp
 test -x $gnomeppp_prog && gnomeppp_entry=$(entry \
     $ICONS/internet-telephony.png \
     "gnome-ppp &" \
-    $"Configure Dial-Up")
+    $"Dial-Up Configuaration (GNOME PPP)")
 
 wpasupplicant_prog=/usr/sbin/wpa_gui
 test -x $wpasupplicant_prog && wpasupplicant_entry=$(entry \
     $ICONS/nm-device-wireless.png \
     "/usr/sbin/wpa_gui &" \
-    $"Configure WPA Supplicant")
+    $"WPA Supplicant Configuration")
 
 pppoeconf_prog=/usr/sbin/pppoeconf
 test -x $pppoeconf_prog && pppoeconf_entry=$(entry \
@@ -344,7 +345,7 @@ arandr_prog=/usr/bin/arandr
 test -x $arandr_prog && arandr_entry=$(entry \
     $ICONS/video-display.png \
     "arandr &" \
-    $"Set Screen Resolution")
+    $"Set Screen Resolution (ARandR)")
 
 gksu_prog=/usr/bin/gksu-properties
 test -x $gksu_prog && gksu_entry=$(entry \
@@ -374,7 +375,7 @@ automount_prog=/usr/local/bin/automount-config
 test -x $automount_prog && automount_entry=$(entry \
     $ICONS/mountbox.png \
     "automount-config &" \
-    $"Configure Automounting")
+    $"Configure Automount")
 
 mountbox_prog=/usr/local/bin/mountbox
 test -x $mountbox_prog && mountbox_entry=$(entry \
@@ -388,13 +389,13 @@ if test -x $liveusb_prog_g; then
 liveusb_entry=$(entry \
     $ICONS/usb-creator.png \
     "gksu live-usb-maker-gui-antix &" \
-    $"Create Live-USB")
+    $"Live USB Maker (gui)")
 
 elif test -x $liveusb_prog; then
 liveusb_entry=$(entry \
     $ICONS/usb-creator.png \
      "desktop-defaults-run sudo &live-usb-maker &" \
-     $"Create Live-USB")
+     $"Live USB Maker (cli)")
 fi
 
 installer_prog=/usr/sbin/minstall
@@ -437,13 +438,13 @@ mouse_prog=/usr/local/bin/ds-mouse
 test -x $mouse_prog && mouse_entry=$(entry \
     $ICONS/input-mouse.png \
     "ds-mouse &" \
-    $"Configure Mouse")
+    $"Mouse Configuration")
 
 soundcard_prog=/usr/local/bin/alsa-set-default-card
 test -x $soundcard_prog && soundcard_entry=$(entry \
     $ICONS2/soundcard.png \
     "alsa-set-default-card &" \
-    $"Set Default Sound Card")
+    $"Sound Card Chooser")
 
 mixer_prog=/usr/bin/alsamixer
 test -x $mixer_prog && mixer_entry=$(entry \
@@ -460,13 +461,13 @@ ndiswrapper_prog=/usr/sbin/ndisgtk
 test -x $ndiswrapper_prog && ndiswrapper_entry=$(entry \
     $ICONS/jockey.png \
     "gksu /usr/sbin/ndisgtk &" \
-    $"MS Windows Wireless Drivers")
+    $"Windows Wireless Drivers")
 
 snapshot_prog=/usr/bin/iso-snapshot
 test -x $snapshot_prog && snapshot_entry=$(entry \
     $ICONS/gnome-do.png \
     "gksu iso-snapshot &" \
-    $"Create Snapshot (ISO)")
+    $"ISO Snapshot")
 
 soundtest_prog=/usr/bin/speaker-test
 test -x $soundtest_prog  && soundtest_entry=$(entry \
@@ -480,10 +481,10 @@ test -x $menumanager_prog && menumanager_entry=$(entry \
     "sudo menu_manager.sh &" \
     $"Menu Editor")
 
-usermanager_prog=/usr/local/bin/user-management
+usermanager_prog=/usr/sbin/antix-user
 test -x $usermanager_prog && usermanager_entry=$(entry \
-    $ICONS/config-users.png \
-    "gksu user-management &" \
+    $ICONS/user-manager.png \
+    "gksu antix-user &" \
     $"User Manager")
 
 galternatives_prog=/usr/bin/galternatives
@@ -496,25 +497,25 @@ codecs_prog=/usr/sbin/codecs
 test -x $codecs_prog && codecs_entry=$(entry \
     $ICONS2/codecs.png \
     "gksu codecs &" \
-    $"Install Restricted Codecs")
+    $"Codecs Installer")
 
 broadcom_prog=/usr/sbin/broadcom-manager
 test -x $broadcom_prog && broadcom_entry=$(entry \
     $ICONS/palimpsest.png \
     "gksu broadcom-manager &" \
-    $"Network Troubleshooting")
+    $"Broadcom Manager")
 
 netassist_prog=/usr/sbin/network-assistant
 test -x $netassist_prog && netassist_entry=$(entry \
     $ICONS/network-wired-disconnected.png \
     "gksu network-assistant &" \
-    $"Network Troubleshooting")
+    $"Network Assistant")
 
 repomanager_prog=/usr/bin/repo-manager
 test -x $repomanager_prog && repomanager_entry=$(entry \
     $ICONS/repo-manager.png \
     "gksu repo-manager &" \
-    $"Manage APT Repositories")
+    $"Repo Manager")
 
 which backlight-brightness &>/dev/null && [ -n "$(ls /sys/class/backlight 2>/dev/null)" ] \
     && backlight_entry=$(entry \
@@ -553,7 +554,7 @@ else
 fi
 
 export ControlCenter=$(cat<<Control_Center
-<window title="antiX Control Center" icon="gnome-control-center" window-position="1">
+<window title="antiX Control Centre" icon="gnome-control-center" window-position="1">
   <vbox>
 <notebook tab-pos="0" labels="$tab_labels">
 $(vbox_frame_hbox \
